@@ -6,7 +6,7 @@
 from collections import deque
 from typing import Optional
 
-from f1z1_common import is_validators
+from f1z1_common.src.is_ import is_validate
 
 from ..speed import IAwaitSpeed
 from .base import IAwaitBuffer, IterOrList
@@ -41,7 +41,7 @@ class AwaitBufferQueue(IAwaitBuffer):
             await self._speed
 
     def _to_iter_or_list(self, iter_or_list: IterOrList) -> IterOrList:
-        return [] if not is_validators.is_iterable(iter_or_list) else iter_or_list
+        return [] if not is_validate.is_iterable(iter_or_list) else iter_or_list
 
     def __str__(self):
         return f"{self.__class__.__name__}(buffer={str(self._buffer)}, speed={self._speed})"
